@@ -1,5 +1,5 @@
 package DBIx::Class::DeploymentHandler::Types;
-$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002222';
+$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002223';
 use strict;
 use warnings;
 
@@ -13,6 +13,13 @@ coerce 'DBIx::Class::DeploymentHandler::Databases'
  => from 'Str'
  => via { [$_] };
 
+subtype 'DBIx::Class::DeploymentHandler::VersionNonObj'
+ => as 'Str';
+
+coerce 'DBIx::Class::DeploymentHandler::VersionNonObj'
+ => from 'Object'
+ => via { $_->numify };
+
 no Moose::Util::TypeConstraints;
 1;
 
@@ -32,7 +39,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2019 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
